<?php
/**
 * An interface for (mostly) file input/output pointers.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface InputOutputPointer extends InputPointer, OutputPointer {
	/**
	 * Rewinds to the beginning of the file
	 *
	 * @return	$status		Status of this operation
	 */
	function rewind ();

	/**
	 * Advances to next "block" of bytes
	 *
	 * @return	void
	 */
	function next ();

	/**
	 * Checks wether the current entry is valid (not at the end of the file).
	 * This method will return TRUE if an emptied (nulled) entry has been found.
	 *
	 * @return	$isValid	Whether the next entry is valid
	 */
	function valid ();

	/**
	 * Gets current seek position ("key").
	 *
	 * @return	$key	Current key in iteration
	 */
	function key ();
}

// [EOF]
?>
